@@ -43,20 +43,21 @@ def standard_bar_tunning(url,ticker,num_bar, date_tuple_range):
 
     #obtener el url para aperturar el Zarr
     url = url+ticker+'.zarr'
-    
+    print("url: ",url)
     #apertura remota de zarr
     zarrds = zarr.open_group(url)
-
+    print("zarrds: ",zarrds.value[0])
     #si la tupla de fechas tiene un valor distinto a None (str fecha x 2)
     #abre todas las fechas
     zarr_dates = zarrds.date.get_basic_selection()
 
     #encuentra los idxs de la fecha min y fecha max dada en la tupla
     dateIdxs = np.searchsorted(zarr_dates, date_tuple_range)
-        
+    print("dateIdxs :",dateIdxs)
+    print("date_tuple_range: ",date_tuple_range)    
     #guarda número de días del zarr| dif. de indexes
     num_days = dateIdxs[1]-dateIdxs[0]
-    
+    print("num_days: ", num_days)
     #guarda número prom diario de ticks, volumen o dollar | init: 0 all
     average_ticks_day, average_volume_day, average_dollar_day = 0, 0, 0
 
@@ -697,4 +698,4 @@ def etfTrick(list_bars_stocks,
         #final_frame.to_csv(
         #    bar_dir + "SERIES_" + bartype + "_ETFTRICK.csv", index=False
         #    )
-        return final_frame #"ETFTrick Saved"
\ No newline at end of file
+        return final_frame #"ETFTrick Saved"
