@@ -6,6 +6,8 @@ webpage: https://www.quantmoon.tech//
 import zarr
 import pyodbc
 import numpy as np
+
+
 import pandas as pd
 from itertools import chain
 from enigmx.utils import (
@@ -46,28 +48,35 @@ class QuantmoonSQLManager(object):
         - '__configurateWrittingInfo__'
         
     """
-    def __init__(self, server, database_name, 
-                 base_database='TSQL', globalRange=False,
-                 loggin='', access=''):
+    def __init__(self, server, database_name, driver,uid,pwd,
+                 base_database='test', globalRange=False,
+                 loggin="",
+                 access=""):
         
         self.server = server
         self.base_database = base_database
 
         self.globalRange = globalRange
+
+        self.driver = driver
+        self.uid = uid
+        self.pwd = pwd
         
-        self.loggin = ('Driver={SQL Server};Server='+server+
-                       ';Trusted_Connection=yes;')
-        
-        self.database_name = database_name.upper() 
+        self.database_name = database_name.upper()
+        print(self.server,self.database_name,self.uid,self.pwd)
+
+        self.loggin = ('Driver='+self.driver[0]+';Server='+ self.server +
+                       ';Database='+self.base_database+';Uid='+self.uid[0]+';Pwd='+self.pwd[0]+';')
+        print(self.loggin)
             
         if self.globalRange:
             self.global_ = '_GLOBAL'
         else:
             self.global_ = '_NOGLOBAL'
             
-        self.access = ('Driver={SQL Server};Server='+ server +
-                       ';Database='+ self.database_name +
-                       ';Trusted_Connection=yes;')
+        self.access = ('Driver='+self.driver[0]+';Server='+ self.server +
+                       ';Database='+self.database_name+';Uid='+self.uid[0]+';Pwd='+self.pwd[0]+';')
+        print(self.access)
         
     def __checkDatabase__(self):
         # revisar si la base de datos ya existe con ese nombre
@@ -485,7 +494,7 @@ class DataRespositoryInitialization(object):
         self.zarrObject = zarr.open(
             self.data_dir+"/"+ self.stock +".zarr"
             )
-        
+        print("zarrObject: ",self.zarrObject.value[0])
         self.zarrDates = np.array(
             self.zarrObject.date)
         
@@ -493,7 +502,7 @@ class DataRespositoryInitialization(object):
         
         #check if days are well-defined
         if check_days: 
-            
+                   
             if type(self.start_date) != str:
                 raise ValueError(
                         'Only string type for start_date and end_date'
@@ -508,17 +517,18 @@ class DataRespositoryInitialization(object):
                                     )
         else:
             self.range_dates = [self.start_date]
-            
+        print("range_dates: ",self.range_dates)     
+        print("zarr dates: ",self.zarrDates)
         #Get ticks information of Time, Prices and Vol from Zarr Objects    
         self.infoTimePriceVol = open_zarr_general(
             self.zarrDates, self.range_dates, self.zarrObject
             ) 
-        
+        print("infoTimePriceVol: ",self.infoTimePriceVol)
         #Check ticks information for removing/fixed missed values
         self.__stateResults__ = check_zarr_data(
             self.infoTimePriceVol
             )
-        
+        print("stateresults: ",self.__stateResults__)
     
     def __makeTupleContent__(self, freq, time):
         """
@@ -640,6 +650,7 @@ class DataRespositoryInitialization(object):
                 time: 'd'
             
         """
+        print("barnovect: ",info_tuple)
             
         if bartype=='tick':
             
@@ -833,8 +844,9 @@ class DataRespositoryInitialization(object):
         """
         
         # método en desuso para computar las barras 
-        
+        print("freq y time: ", freq,time)    
         info_tuple = self.__makeTupleContent__(freq, time)
+        print("info_tuple databundle.py: ",info_tuple)
         
         daily_time_bars = info_tuple[3]
         
@@ -921,4 +933,4 @@ class DataRespositoryInitialization(object):
             
             
     
-    
\ No newline at end of file
+    
