@@ -133,16 +133,19 @@ class SQLEnigmXinterface(object):
         - '__sampleWeights__'
         - '__featuresComputation__'
  
-        
+    WARNING: considerar como fecha de inicio (start_date), la fecha más antigua + el intervalo de 
+   tunning.
     """
-    def __init__(self, server, 
+    def __init__(self, driver,uid,pwd,server, 
                  pathzarr, list_stocks, 
                  bartype, start_date, 
                  end_date, desired_bars, 
                  global_range=True):
         
         self.database_features = 'BARS_FEATURES'
-        
+        self.driver = driver,
+        self.uid = uid,
+        self.pwd = pwd,        
         self.server_name = server
         self.pathzarr = pathzarr
         self.list_stocks = list_stocks
@@ -153,7 +156,7 @@ class SQLEnigmXinterface(object):
         self.global_range = global_range
         
     def __barTunningProcess__(self, SQLFRAME, dbconn, cursor, tunning_interval):
-                
+        
         #fecha inicial a partir de la fecha final (parametro "start_date")
         data_tuple_range_for_tunning = (
             (
@@ -162,7 +165,7 @@ class SQLEnigmXinterface(object):
                 ).strftime('%Y-%m-%d'), 
             self.start_date
             )
-        
+        print("path: "+self.pathzarr)
         #obtien obj. ray con los parametros tuneados por tipo de barra (dict)
         ray_object_list = [
             standard_bar_tunning.remote(
@@ -177,7 +180,7 @@ class SQLEnigmXinterface(object):
         
         #obten la lista de información con los diccionarios
         list_datasets =  ray.get(ray_object_list)
-        
+        print(list_datasets) 
         #transforma los diccionarios en un pandas con los params de tunning x bar
         tunning_pandas = construct_pandas_tunning(list_datasets, self.list_stocks)
         
@@ -666,6 +669,7 @@ class SQLEnigmXinterface(object):
             bartype_database = 'TUNNING'
                 
             SQLFRAME, dbconn, cursor = databundle_instance(
+                    driver = self.driver, uid = self.uid, pwd = self.pwd,
                     #nombre del servidor SQL Local
                     server = self.server_name, 
                     #nombre que se le asignará a la base de datos matriz
@@ -697,6 +701,7 @@ class SQLEnigmXinterface(object):
             bartype_database = 'BARS'
             
             SQLFRAME, dbconn, cursor = databundle_instance(
+                    driver = self.driver, uid = self.uid, pwd = self.pwd,
                     #nombre del servidor SQL Local
                     server = self.server_name, 
                     #nombre que se le asignará a la base de datos matriz
@@ -727,7 +732,8 @@ class SQLEnigmXinterface(object):
             bartype_database = 'ENTROPY'
                 
             SQLFRAME, dbconn, cursor = databundle_instance(
-                    #nombre del servidor SQL Local
+
+                    driver = self.driver, uid = self.uid, pwd = self.pwd,                    #nombre del servidor SQL Local
                     server = self.server_name, 
                     #nombre que se le asignará a la base de datos matriz
                     bartype_database = bartype_database,
@@ -758,6 +764,7 @@ class SQLEnigmXinterface(object):
             bartype_database = 'ETFTRICK'
                 
             SQLFRAME, dbconn, cursor = databundle_instance(
+                    driver = self.driver, uid = self.uid, pwd = self.pwd,
                     #nombre del servidor SQL Local
                     server = self.server_name, 
                     #nombre que se le asignará a la base de datos matriz
@@ -821,6 +828,7 @@ class SQLEnigmXinterface(object):
             bartype_database = 'BARS_SAMPLED'
                 
             SQLFRAME, dbconn, cursor = databundle_instance(
+                    driver = self.driver, uid = self.uid, pwd = self.pwd,
                     #nombre del servidor SQL Local
                     server = self.server_name, 
                     #nombre que se le asignará a la base de datos matriz
@@ -855,6 +863,7 @@ class SQLEnigmXinterface(object):
             bartype_database = 'BARS_COMPLETED'
                 
             SQLFRAME, dbconn, cursor = databundle_instance(
+                    driver = self.driver, uid = self.uid, pwd = self.pwd,
                     #nombre del servidor SQL Local
                     server = self.server_name, 
                     #nombre que se le asignará a la base de datos matriz
@@ -886,6 +895,7 @@ class SQLEnigmXinterface(object):
             bartype_database = 'BARS_WEIGHTED'
                 
             SQLFRAME, dbconn, cursor = databundle_instance(
+                    driver = self.driver, uid = self.uid, pwd = self.pwd,
                     #nombre del servidor SQL Local
                     server = self.server_name, 
                     #nombre que se le asignará a la base de datos matriz
@@ -916,6 +926,7 @@ class SQLEnigmXinterface(object):
             bartype_database = self.database_features
                 
             SQLFRAME, dbconn, cursor = databundle_instance(
+                    driver = self.driver, uid = self.uid, pwd = self.pwd,
                     #nombre del servidor SQL Local
                     server = self.server_name, 
                     #nombre que se le asignará a la base de datos matriz
@@ -967,6 +978,7 @@ class SQLEnigmXinterface(object):
         
         #valores de ejecución: instancia SQL, conexión a la base de datos, cursor
         SQLFRAME, dbconn, cursor = databundle_instance(
+            driver=self.driver,uid=self.uid,pwd=self.pwd,
             #nombre del servidor SQL Local
             server = self.server_name, 
             #nombre que se le asignará a la base de datos matriz
