@@ -116,8 +116,7 @@ def generate_datasets(stock,
             )
     
     list_of_list = []
-            
-    
+    print("alpha ",alpha_calibration)            
     #iteración simple día x día para cálculo de barras
     for date in range_dates:            
 
@@ -130,14 +129,16 @@ def generate_datasets(stock,
                                 )
 
         #iteración por tipo de barra | result_value: numpy.array
+        
+        
+        print("daily_time_bars_organization: ",alpha_calibration['volume_t'].item())
         result_value = [
             QMREPOSITORY.geneticIterativeFunction(
                 freq = bar_grp_freq,
                 time = bar_grp_horizon,
                 bartype = bartype,
                 imbalance_list = imbalance_dict[stock], 
-                daily_time_bars_organization=\
-                    alpha_calibration[bartype+'_t'].item()
+                daily_time_bars_organization=alpha_calibration[bartype+'_t'].item()
                 )
             for bartype in bartypesList]
 
